@@ -2,6 +2,7 @@
 
 namespace Application\Migrations;
 
+use Doctrine\DBAL\Platforms\SqlitePlatform;
 use Doctrine\DBAL\Schema\Schema;
 use Wallabag\CoreBundle\Doctrine\WallabagMigration;
 
@@ -15,7 +16,7 @@ class Version20160812120952 extends WallabagMigration
         $clientsTable = $schema->getTable($this->getTable('oauth2_clients'));
         $this->skipIf($clientsTable->hasColumn('name'), 'It seems that you already played this migration.');
 
-        if ('sqlite' === $this->connection->getDatabasePlatform()->getName()) {
+        if ($this->connection->getDatabasePlatform() instanceof SqlitePlatform) {
             // Can't use $clientsTable->addColumn('name', 'blob');
             // because of the error:
             // SQLSTATE[HY000]: General error: 1 Cannot add a NOT NULL column with default value NULL
@@ -35,7 +36,7 @@ class Version20160812120952 extends WallabagMigration
     {
         $clientsTable = $schema->getTable($this->getTable('oauth2_clients'));
 
-        if ('sqlite' === $this->connection->getDatabasePlatform()->getName()) {
+        if ($this->connection->getDatabasePlatform() instanceof SqlitePlatform) {
             $databaseTablePrefix = $this->container->getParameter('database_table_prefix');
             $this->addSql('DROP INDEX IDX_635D765EA76ED395');
             $this->addSql('CREATE TEMPORARY TABLE __temp__' . $databaseTablePrefix . 'oauth2_clients AS SELECT id, random_id, redirect_uris, secret, allowed_grant_types FROM ' . $databaseTablePrefix . 'oauth2_clients');
